@@ -3,7 +3,7 @@ package Combine::Keys;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 require XSLoader;
 XSLoader::load('Combine::Keys', $VERSION);
 
@@ -20,18 +20,19 @@ sub import {
 
 sub export {
 	my ($pkg, $caller) = (shift, shift);
-	for my $meth ( @_ ) {
-		if (! exists $EXPORTING{$meth} ) {
+	while (my $ex = shift) {
+		if (! exists $EXPORTING{$ex} ) {
 		 	my @export = grep { 
-				grep { $_ eq $meth } @{ $EXPORTING{$_} }
+				grep { $_ eq $ex } @{ $EXPORTING{$_} }
 			} keys %EXPORTING;
 			@export 
-				? export($pkg, $caller, @export)
-				: die "$meth is not exported";
+				? return export($pkg, $caller, (@export, @_))
+				: die "$ex is not exported";
 		}
-
+		
 		no strict 'refs';
-		*{"${caller}::${meth}"} = \&{"${pkg}::${meth}"};
+		$caller->can($ex) and next; # qw/all perl/
+		*{"${caller}::${ex}"} = \&{"${pkg}::${ex}"};
 	}
 }
 
@@ -45,7 +46,7 @@ Combine::Keys - keys on multiple hash references
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
